#!/usr/bin/env python

# add_gimp_decor Rel 3
# Created by Tin Tran http://bakon.ca/gimplearn/
# Comments directed to http://gimpchat.com or http://gimpscripts.com
#
# License: GPLv3
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY# without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# To view a copy of the GNU General Public License
# visit: http://www.gnu.org/licenses/gpl.html
#
#
# ------------
#| Change Log |
# ------------
# Rel 1: Initial release.
# Rel 2: Added ability to change font, and font size
# Rel 3: Added ability to Text Justify
import math
import string
from gimpfu import *
from array import array

def add_text(image,layer,text,font,fontsize,justify):
	layerheight = layer.height
	
    #adds black text a little shifted
	shift_x = 1
	shift_y = 1
	pdb.gimp_context_set_foreground((0,0,0))
	text_layer = pdb.gimp_text_layer_new(image,text,font,fontsize,0)
	pdb.gimp_image_insert_layer(image,text_layer,None,-1)
	
	pdb.gimp_text_layer_resize(text_layer,layer.width-20,text_layer.height)
	pdb.gimp_text_layer_set_justification(text_layer,justify)
	
	pdb.gimp_layer_translate(text_layer,10+shift_x,layerheight - (text_layer.height + 5) + shift_y)
	
	#adds white text not shifted
	pdb.gimp_context_set_foreground((255,255,255))
	text_layer2 = pdb.gimp_text_layer_new(image,text,font,fontsize,0)
	pdb.gimp_image_insert_layer(image,text_layer2,None,-1)
	
	pdb.gimp_text_layer_resize(text_layer2,layer.width-20,text_layer2.height)
	pdb.gimp_text_layer_set_justification(text_layer2,justify)
	
	pdb.gimp_layer_translate(text_layer2,10,layerheight - (text_layer.height + 5))
	
	#merge white text onto black text, then merge that down to layer.
	merged_text_layer = pdb.gimp_image_merge_down(image,text_layer2,EXPAND_AS_NECESSARY)
	pdb.gimp_image_merge_down(image,merged_text_layer,EXPAND_AS_NECESSARY)
	

def python_add_gimp_decor(image, layer, text, font, fontsize, justify, location):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()
	
	apply_layers = list(image.layers)

	
	if location == 1: #if extend bottom add canvas size
		#try creating text to grab how much space we should extend bottom
		text_layer = pdb.gimp_text_layer_new(image,text,font,fontsize,0)
		pdb.gimp_image_insert_layer(image,text_layer,None,-1)
		pdb.gimp_image_resize(image,image.width,image.height+(text_layer.height+5),0,0)
		
		pdb.gimp_image_remove_layer(image,text_layer)
		
	#resize all layers to image size after adding alpha
	for layer in apply_layers:
		if layer.has_alpha == 0:
			pdb.gimp_layer_add_alpha(layer)
		pdb.gimp_layer_resize_to_image_size(layer)
		pdb.gimp_image_set_active_layer(image,layer)
		add_text(image,layer,text,font,fontsize,justify)
		
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()
    #return

register(
	"python_fu_add_gimp_decor",
	"Add Text to bottom of image (all layers) saying Created/Edited in Gimp",
	"Add Text to bottom of image (all layers) saying Created/Edited in Gimp...",
	"Tin Tran",
	"Tin Tran",
	"2014",
	"<Image>/Python-Fu/Add Gimp Decor...",
	"RGB*, GRAY*", 
	[
	(PF_TEXT, "text", "Multiline Text:", "Created/Edited in GIMP\nfor http://bakon.ca/gimplearn/"),
	(PF_FONT, "font", "Font:", "Sans"),
	(PF_SPINNER, "fontsize", "Font Size(pixels):", 10, (10, 500, 1)),
	(PF_OPTION,"justify",   "Text Justify:", 0, ["LEFT","RIGHT","CENTER","FILL"]),
	(PF_OPTION,"location",   "Location:", 0, ["On Bottom","Extend Bottom"]),
	],
	[],
	python_add_gimp_decor)

main()
